@@ -1,8 +1,10 @@
-qloglin <- function(u, t){
-    if (abs(t) > 1e-6){
-        z <- log(1 + ((exp(t) - 1) * u)) / t} else {
-        z <- u + t * u * (1 - u) / 2}
-    return(z)
+qloglin <- function(u, t) {
+  if (abs(t) > 1e-6) {
+    z <- log(1 + ((exp(t) - 1) * u)) / t
+  } else {
+    z <- u + t * u * (1 - u) / 2
+  }
+  return(z)
 }
 
 
@@ -17,4 +19,3 @@ qloglin <- function(u, t){
 #     z[II] <- u[II] + t * u[II]*(1-u[II])/2
 #     return(z)
 # }
-
